From: Haiyang Zhang <haiya...@microsoft.com>

Added a condition to avoid bonding devices with same MAC registering
as VF.

Signed-off-by: Haiyang Zhang <haiya...@microsoft.com>
Reviewed-by: K. Y. Srinivasan <k...@microsoft.com>
---
 drivers/net/hyperv/netvsc_drv.c |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)

diff --git a/drivers/net/hyperv/netvsc_drv.c b/drivers/net/hyperv/netvsc_drv.c
index 787a202..41bd952 100644
--- a/drivers/net/hyperv/netvsc_drv.c
+++ b/drivers/net/hyperv/netvsc_drv.c
@@ -1494,8 +1494,8 @@ static int netvsc_netdev_event(struct notifier_block 
*this,
 {
        struct net_device *event_dev = netdev_notifier_info_to_dev(ptr);
 
-       /* Avoid Vlan dev with same MAC registering as VF */
-       if (event_dev->priv_flags & IFF_802_1Q_VLAN)
+       /* Avoid Vlan, Bonding dev with same MAC registering as VF */
+       if (event_dev->priv_flags & (IFF_802_1Q_VLAN | IFF_BONDING))
                return NOTIFY_DONE;
 
        switch (event) {
-- 
1.7.4.1

_______________________________________________
devel mailing list
de...@linuxdriverproject.org
http://driverdev.linuxdriverproject.org/mailman/listinfo/driverdev-devel

Reply via email to